// src/index.ts
import parse from "style-to-object";
function isString(x) {
  return typeof x === "string";
}
function shikiClassTransformer({
  map,
  keys = ["color"],
  deletedKeys = []
}) {
  return {
    tokens(tokens) {
      for (const items of tokens) {
        for (const token of items) {
          const hasHtmlStyle = !!token.htmlStyle;
          let htmlStyle = token.htmlStyle ?? token;
          if (isString(htmlStyle)) {
            htmlStyle = parse(htmlStyle) ?? {};
          }
          for (const key of keys) {
            const foreground = htmlStyle[key]?.toLowerCase();
            if (!foreground) {
              continue;
            }
            const className = map[foreground];
            if (!className) {
              continue;
            }
            if (!token.htmlAttrs) {
              token.htmlAttrs = {};
            }
            if (!hasHtmlStyle) {
              for (const dk of deletedKeys) {
                delete token[dk];
              }
              delete token[key];
            } else {
              delete token.htmlStyle[key];
              for (const dk of deletedKeys) {
                delete token.htmlStyle[dk];
              }
            }
            let originClassName = token.htmlAttrs.class ?? "";
            originClassName += ` ${className}`;
            const afterClassName = originClassName.trim();
            if (afterClassName) {
              token.htmlAttrs.class = afterClassName;
            }
          }
        }
      }
    }
  };
}
export {
  shikiClassTransformer
};
